<?php
/**
   * Purpose:           Helper for JSON and UI functions like WP Options and repeating UI parts
   * Function URI:      https://leftsell.com/
   * Version:           1.0.0
   * Author:            Kundschaft Schweiz
   * Author URI:        https://kundschaft.ch/ 
*/
defined( 'ABSPATH' ) || exit;
class leftsellJSON  {
   function CheckJSON( $json ) {
      $test = json_decode( $json, true);
      switch( json_last_error() ) {
         case JSON_ERROR_NONE:  return true; break;
         default:               return false; break;
      }
   }
   function ToJSON( $ary ) { // return json string
      return json_encode($ary);
   }
   function aryFromJSONOption( $option ) {
      $json = get_option( $option );
      return $this->FromJSON( $json );
   }
   function aryToJSONOption ( $ary, $option ) {
      $this->ToOption ( $this->ToJSON( $ary ), $option );
   }
   function FromJSON( $json ) { // return array
      $json = stripslashes( $json ); 
      $aryResult = json_decode( $json, true );
      if ($aryResult == null) {
         return array();
      } else {
         return $aryResult;
      }
   }
   function ToOption($strJSON, $strOptionName) {
      $deprecated = null;
      $autoload = 'no';
      update_option ( sanitize_text_field( $strOptionName ), sanitize_text_field( $strJSON ), $deprecated, $autoload );
   }
} // end class leftsellJSON

class leftsellUI {
   function GetOptionSwitch( $option ) {
      $aryCall = array( "call" => "changeoption", "option" => $option );
      $call    = esc_html( json_encode( $aryCall ) );
      $image   = 'disabled.png';
      if ( get_option( $option ) == 1 ) { $image = 'enabled.png'; }
      return '<div id="' . $option . '"><img onclick="leftsellAJAX_event(\'' . esc_js( $call ) . '\', \'' . esc_js( $option ) . '\' , \'\' );" 
                  class="leftsell_check" src="' . leftsellINCLUDE . 'images/' . $image . '" /></div>';
   }
   function GetOptionTextBox( $option, $title, $description ) {
      $buffer = '';
      $value = get_option( $option );
      $value = esc_html ( $value );
      if ( $value == false ) { $value = ''; }
      $buffer .= '<p><strong>' . $title . '</strong><br />' . $description . '</p>';
      $buffer .= '<input id="' . $option . '" class="leftsell_textbox" type="text" value="' . $value . '" onkeydown="document.getElementById(\'btn' . esc_js( $option ) . '\').innerHTML = \'' . esc_html__( 'Save', 'leftsell' ) .'\';" />';
      $buffer .= '<button class="button button-primary" id="btn' . $option . '" onclick="SaveOptionTextBox_' . esc_js( $option ) . '()">' . esc_html__( 'Save', 'leftsell' ) . '</button>';
      $buffer .= '<script type="text/javascript">
                  function SaveOptionTextBox_' . $option . '() {
                     var newvalue = document.getElementById("' . $option . '").value;
                     var strCall = { "call":    "changetextoption", 
                                     "option":  "' . $option . '", 
                                     "value":   newvalue };
                     strCall = JSON.stringify( strCall );
                     leftsellAJAX_event( strCall, "btn' . $option . '" , "" );
                  }
                  </script>';
      return $buffer;
   }
   function BuildNav( $aryTabs, $defaultTab ) {
      $buffer = '<ul id="leftsell_nav" aria-label="Secondary menu">';
      $curTab = $defaultTab;
      if ( isset( $_GET[ "tab" ] ) ) { $curTab = $_GET["tab"]; }
      foreach ($aryTabs as $key=>$description) {
         $tabName = 'tab' .  $key;
         $tabclass = '';
         if ( !isset( $_GET[ "page" ]) ) { return ""; }
         if ($tabName == $curTab) {
            $tabclass = ' class="tabactive" ';
         } 
         $buffer .= '<li ' . $tabclass . '>';
         $buffer .= '<a id="cmd' . $key . '" href="'.admin_url().'admin.php?page=' . $_GET[ "page" ] . '&tab=' . $tabName . '">';
         $buffer .= $description;
         $buffer .= '</a></li>';
      }
      $buffer .= '</ul>';
      return $buffer;
   }
   function BuildDivSwitcher( $aryTabs, $defaultTab ) {
      $buffer  = '<script type="text/javascript">';
      $buffer .= 'function leftsellHideSwitcherDivs( tabActive ) {';
      foreach ($aryTabs as $key=>$description) {
         $buffer .= 'if ( tabActive != "' . $key . '" ) {';
         $buffer .= 'document.getElementById("' . $key .'").style.display = "none";';
         $buffer .= 'document.getElementById("tab' . $key . '").style.fontWeight = "normal";';
         $buffer .= '} else {';
         $buffer .= 'document.getElementById("' . $key . '").style.display = "block";';
         $buffer .= 'document.getElementById("tab' . $key . '").style.fontWeight = "bold";';
         $buffer .= '}';
      }
      $buffer .= '}';
      $buffer .= '</script>';
      $buffer .= '<ul id="leftsell_nav" aria-label="Secondary menu" style="margin-bottom:10px">';
      foreach ( $aryTabs as $key=>$description ) {
         $style = "font-weight:normal";
         if ( $key == $defaultTab ) { $style = "font-weight:bold"; }
         $buffer .= '<li id="tab' . $key . '" onclick="leftsellHideSwitcherDivs(\'' . esc_js( $key ) . '\')" style="cursor:pointer; ' . $style . '">';
         $buffer .= $description;
         $buffer .= '</li>';
      }
      $buffer .= '</ul>';
      return $buffer;
   }
} // end class leftsellUI

?>