<?php
   /**
    * Purpose:           Define and handle message protocol with leftsell server
    * Function URI:      https://leftsell.com/
    * Version:           1.0.0
    * Author:            Kundschaft Schweiz
    * Author URI:        https://kundschaft.ch/ 
   */
   defined( 'ABSPATH' ) || exit;
   function leftsellRESTHandler( WP_REST_Request $request ) { 
      // received data from REST
      $aryParams = $request->get_params();
      if ( isset ( $aryParams["msg"] ) ) {
         $objMsg = new leftsellMessage( sanitize_text_field( $aryParams["msg"] ) );
         return $objMsg->FromREST( $request );
      } else {
         return "Message Error 32";
      }
   }
   function leftSellGetMsgDefinitions() { 
      if ( get_option ( "leftsell_messageupdate" ) == date("Y-m-d", time() ) ) {
         return;
      }
      global $wp_version;
      if ( !function_exists( 'get_home_url' ) ) { require_once ABSPATH . WPINC . '/link-template.php'; } 
      $args = array( 'timeout'     => 10,
                     'redirection' => 5,
                     'httpversion' => '1.0',
                     'user-agent'  => 'leftsell/' . $wp_version . '|' . get_home_url(),
                     'blocking'    => true,
                     'headers'     => array(),
                     'cookies'     => array(),
                     'body'        => null,
                     'compress'    => true,
                     'decompress'  => true,
                     'sslverify'   => false,
                     'stream'      => false,
                     'filename'    => null ); 
         $restURL = leftsellGATE . "&msg=getmsgdef";
         $response = wp_remote_get( $restURL, $args );
         if ( is_wp_error( $response ) ) { return "error"; } 
         $body = wp_remote_retrieve_body( $response );
         $data = json_decode( $body ); // all as string
         $data = sanitize_text_field( $data );
         $objJSON = new leftsellJSON(); 
         $objJSON->ToOption( $data, "leftsell_messagedefintions" );
         $deprecated = null;
         $autoload = 'no';
         update_option ( "leftsell_messageupdate", date("Y-m-d", time() ), $deprecated, $autoload );
         return $data;
   }
   function leftSellSendMessage( $aryParams ) {
      // AJAX callback: send message via REST and handle reply 
      // plugin activation/deactivation/uninstall callback
      if ( isset( $aryParams["msgid"] ) ) {
         $objMsg = new leftsellMessage( sanitize_text_field( $aryParams["msgid"] ) );
         $objMsg->FromArray( $aryParams );
         return $objMsg->SendMessage();
      }
   }
   
   class leftsellMessage {
      public  $m_strName = "";
      public  $m_aryFields = array();
      public  $m_aryParams  = array();    
      public  $m_strCallerURL;
      public  $m_intCallerId;
      private $m_aryAllMessages;  

      function __construct ( $strName ) {
         $this->m_strName = sanitize_text_field( $strName );
         $this->InitMessages();
         if ( isset( $this->m_aryAllMessages[$strName] ) ) {
            $this->m_aryFields = $this->m_aryAllMessages[$strName];
         }
         $this->m_intCallerId = sanitize_text_field( get_option("leftsell_shop_id") );
         if ( !function_exists( 'get_home_url' ) ) {  require_once ABSPATH . WPINC . '/link-template.php'; } 
         $this->m_strCallerURL = get_home_url();
      }

      private function InitMessages() {
         $objJSON = new leftsellJSON();
         $this->m_aryAllMessages = $objJSON->aryFromJSONOption( "leftsell_messagedefintions" );
         if ( count( $this->m_aryAllMessages ) == 0 ) {
            // request messages
            leftSellGetMsgDefinitions();
            $this->m_aryAllMessages = $objJSON->aryFromJSONOption( "leftsell_messagedefintions" );
         }
      }

      public function OnMessage( $objMsg ) {
         // received request message from REST
         if ( !isset( $this->m_aryParams["msg"] ) ) { return "no msg given"; }
         switch ( sanitize_text_field( $this->m_aryParams["msg"] ) ) {
            case "getbugreports": 
               $objJSON = new leftsellJSON;
               $aryStored = $objJSON->aryFromJSONOption( "leftsell_bugregports" );
               $result = $aryStored;
               break;
            case "getfeaturerequests":
               $objJSON = new leftsellJSON;
               $aryStored = $objJSON->aryFromJSONOption( "leftsell_featurerequests" );
               $result = $aryStored;
         }
         return new WP_REST_Response( wp_json_encode($result, JSON_FORCE_OBJECT), 10000 );
      }
      
      public function SendMessage() {
         if ( $this->m_strName == "" ) { leftSellGetMsgDefinitions(); return "326 MsgDef"; }
         global $wp_version;
         if ( !function_exists( 'get_home_url' ) ) {  require_once ABSPATH . WPINC . '/link-template.php'; } 
         $objShop = new leftsellShop();
         $args = array( 'timeout'     => 10,
                        'redirection' => 5,
                        'httpversion' => '1.0',
                        'user-agent'  => 'lefsell/' . $wp_version . '|' . get_home_url(),
                        'blocking'    => true,
                        'headers'     => array(),
                        'cookies'     => array(),
                        'body'        => null,
                        'compress'    => true,
                        'decompress'  => true,
                        'sslverify'   => false,
                        'stream'      => false,
                        'filename'    => null ); 
         $restURL = leftsellGATE . "&shopid=" . $this->m_intCallerId . "&msg=" . $this->m_strName;
         foreach( $this->m_aryFields as $key=>$data ) {
            $restURL .= "&" . sanitize_text_field( $key ) . "=" . sanitize_text_field( $data );
         }
         $objShop = null;
         // get data from remote
         $response = wp_remote_get( $restURL, $args);
         if ( is_wp_error( $response ) ) { return "error"; } 
         $body = wp_remote_retrieve_body( $response ); 
         $data = sanitize_text_field( json_decode( $body ) , [] ) ; // all as string
         $data = json_decode( $data, true );            // to array
         return $this->HandleReply( $data ) ;
      }

      private function HandleReply( $data ) {
         // got result from requested REST call
         switch ( $this->m_strName ) {
            case "reg":
               $objShop = new leftsellShop();
               return $objShop->Register( $data );
               break;
            case "news":
               return nl2br( $data );
               break;

            default: return $data; break;
         }
         
      }
      
      // receive messages ----------------------------------------------------
      public function FromREST(WP_REST_Request $request) { 
         $this->m_aryParams = $request->get_params();
         $user_agent = sanitize_text_field( $request->get_header( "user_agent" ) );
         $aryTemp = explode( "|", $user_agent );
         if ( is_array( $aryTemp ) ) {
            if ( count( $aryTemp ) > 1 ) {
               $this->m_strCallerURL = $aryTemp[1];
            }
         }
         $aryTemp = null;
         return $this->OnMessage( $this );
      }

      public function FromArray($ary) {
         if ( isset( $ary["m_strName"] ) )      { $this->m_strName      = sanitize_text_field( $ary["m_strName"] ); }
         if ( isset( $ary["m_aryFields"] ) )    { $this->m_aryFields    = $ary["m_aryFields"]; }
         if ( isset( $ary["m_aryParams"] ) )    { $this->m_aryParams    = $ary["m_aryParams"]; }
         if ( isset( $ary["m_intCallerId"] ) )  { $this->m_intCallerId  = sanitize_text_field( $ary["m_intCallerId"] ); }
         if ( isset( $ary["m_strCallerURL"] ) ) { $this->m_strCallerURL = sanitize_text_field( $ary["m_strCallerURL"] ); }
      }
   }
   class leftsellCom {
      public function ReportBug( $aryParams ) {
         if ( isset ( $aryParams["value"] ) ) {
            if ( $aryParams["value"] == "" ) {
               return esc_html__( 'Nothing to transmit error 549', 'leftsell' );
            }
            // store locally
            $objJSON = new leftsellJSON;
            $aryStored = $objJSON->aryFromJSONOption( "leftsell_bugregports" );
            $aryStored[] = array( "reportdate" => date("d.m.Y", time()) , "text" => $aryParams["value"], "answer" => "", "submitted" => 0 );
            $objJSON->aryToJSONOption( $aryStored, "leftsell_bugregports" );
            // request server fetch
            $objMsg = new leftsellMessage( "bugreport" );
            $strReply = $objMsg->SendMessage();
            $objMsg = null;
            if ($strReply == "OK") {
               return esc_html__( 'Bug successfully transmitted','leftsell' );
            } else {
               return $strReply;
            }
         } else {
            return esc_html__( 'Transmission error 548', 'leftsell' );
         }
      }

      public function RequestFeature( $aryParams ) {
         if ( isset ( $aryParams["value"] ) ) {
            if ( $aryParams["value"] == "" ) {
               return esc_html__( 'Nothing to transmit error 550', 'leftsell' );
            }
            // store locally
            $objJSON = new leftsellJSON;
            $aryStored = $objJSON->aryFromJSONOption( "leftsell_featurerequests" );
            $aryStored[] = array( "requestdate" => date("d.m.Y", time()) , "featuretext" => $aryParams["value"]);
            $objJSON->aryToJSONOption( $aryStored, "leftsell_featurerequests" );
            // request server fetch
            $objMsg = new leftsellMessage( "featurerequest" );
            $strReply = $objMsg->SendMessage();
            $objMsg = null;
            if ($strReply == "OK") {
               return esc_html__( 'Feature request successfully transmitted', 'leftsell' );
            } else {
               return $strReply;
            }
         } else {
            return esc_html__( 'Transmission error 551', 'leftsell' );
         }
      }   
   } // end class leftsellCom
?>