<?php
defined( 'ABSPATH' ) || exit;
class leftsellShop {
   public $m_intId      = 0;
   public $m_intReg     = 0;
   public $m_intEnabled = 0;
   public $m_intBlock   = 0;
   function __construct () {
      $shopid = get_option( "leftsell_shop_id" );
      if ( $shopid != "" ) {
         $this->m_intId = $shopid;
      }
      $this->m_intBlock   = get_option( "leftsell_shop_blocked" );
      $this->m_intEnabled = get_option( "leftsell_shop_enabled" );
   }
   public function Register( $result ) {
      if ( intval( $result ) > 0 ) {
         $deprecated = null;
         $autoload = 'no';
         update_option ( "leftsell_shop_id", $result, $deprecated, $autoload );
         update_option ( "leftsell_shop_enabled", 1, $deprecated, $autoload );
         update_option ( "leftsell_shop_blocked", 0, $deprecated, $autoload );
         return esc_html__( 'Successfully registered. Please reload page.', 'leftsell' );
      }
      if ( $result == "blocked" ) {
         $deprecated = null;
         $autoload = 'no';
         update_option ( "leftsell_shop_blocked", 1, $deprecated, $autoload );
         return esc_html__( 'Blocked', 'leftsell' );
      }
      return $result;
   }
} // end class leftsellShop

class leftsellProduct {
   public $fields = array( 
      // leftsell fields
      "leftsellid"              => "",         // leftsell V2 id
      "shopurl"                 => "",         // leftsell V2 shop link
      "shopid"                  => "",         // leftsell V2 shop id
      "shopname"                => "",         // leftsell V2 shop name
      "provision"               => "",         // leftsell V3 seller provision as amount
      
      // google relevant
      "wpid"                    => "",         // google product relevant: wp id
      "title"                   => "",         // google product relevant: wp title
      "text"                    => "",         // google product relevant: woo product text
      "link"                    => "",         // google product relevant: woo product url
      "imagelink"               => "",         // google product relevant: woo featured image url
      "price"                   => "",         // google product relevant: woo price
      "condition"               => "new",      // google product relevant: new, used or refurbished
      "availability"            => "",         // google product relevant: woo stock
      "identifierexists"        => "no",       // google product relevant: yes (has gtin, mpn or brand), no (no numbers)
      "google_product_category" => "",         // google product category
      
      // woo
      "slug"                    => "",         // wp slug 
      "virtual"                 => "",         // woo real product or virtual 
      "shortdescription"        => "",         // woo
      "categories"              => array(""),  // product categories
      "regularprice"            => "",         // regular price
      "saleprice"               => "",         // sale price
      "onsale"                  => "",         // on sale
      "currencysymbol"          => "",         // currency
      "currency"                => "",         // mapped to shortcode currency
      "soldindiviually"         => "",         // sold individually
      "datemodified"            => "",         // date
      "datecreated"             => "",         // date
      "status"                  => "",         // status
      "featured"                => "",         // is featured
      
      // leftsell
      "sku"                     => "",         // sku
      "gtin"                    => "",         // gtin
      "mpn"                     => "",         // mpn
      "brand"                   => "",         // google product brand (required)
      "adult"                   => "no",       // google product relevant: sexual content, no or yes

      // kcms
      "metapath"                => "",         // kcms relevant
      "metaid"                  => ""          // kcms relevant

      );
   public function fromPost( $post ) {
      // wordpress fields
      $this->fields[ "wpid" ]              = $post->ID;
      $this->fields[ "title" ]             = $post->post_title;   // can be overwritten by shop systems
      $this->fields[ "text" ]              = $post->post_content; // can be overwritten by shop systems
      $this->fields[ "link" ]              = get_permalink( $post->ID );
      $this->fields[ "shortdescription" ]  = $post->post_excerpt; // can be overwritten by shop systems
      $this->fields[ "slug" ]              = $post->post_name;    // can be overwritten by shop systems
      $this->fields[ "shopname" ]          = get_bloginfo( "name" );    
      
      // leftsell fields
      $this->fields[ "sku" ]              = get_post_meta( $post->ID, "_sku", true );
      $this->fields[ "gtin" ]             = get_post_meta( $post->ID, "_gtin", true );
      $this->fields[ "mpn" ]              = get_post_meta( $post->ID, "_mpn", true );
      $this->fields[ "brand" ]            = get_post_meta( $post->ID, "_brand", true );
      $this->fields[ "condition" ]        = get_post_meta( $post->ID, "_condition", true );
      $this->fields[ "adult" ]            = get_post_meta( $post->ID, "_adult", true );
      
      // shop systems
      if ( class_exists( 'WooCommerce' ) ) {
         $this->MapWoocommerce( $post );
      }
      $this->MapKCMS( $post );

      // logical fields
      if ( $this->fields[ "brand" ] == "" ) {
         $this->fields[ "brand" ] = $this->fields[ "shopname" ];
      }
      if ( $this->fields[ "sku" ] != "" ) {
         $this->fields[ "identifierexists" ]    = "yes";
      }
      if ( $this->fields[ "mpn" ] != "" ) {
         $this->fields[ "identifierexists" ]    = "yes";
      }
      if ( $this->fields[ "gtin" ] != "" ) {
         $this->fields[ "identifierexists" ]    = "yes";
      }
      if ( $this->fields[ "condition" ] == "" ) {
         $this->fields[ "condition" ] = "new";
      }
      if ( $this->fields[ "adult" ] == "" ) {
         $this->fields[ "adult" ] = "no";
      }

      // final maps
      $this->fields[ "currency" ] = $this->MapCurrencySymbol( $this->fields[ "currencysymbol" ] );

   }
   private function MapWoocommerce( $post ) {
      $product = wc_get_product( $post->ID );
      $this->fields[ "imagelink" ]        = $this->ImageURL( $product->get_image('view') );
      $this->fields[ "slug" ]             = $product->get_slug();
      $this->fields[ "virtual" ]          = $product->get_virtual();
      $this->fields[ "shortdescription" ] = $product->get_short_description();
      $this->fields[ "title" ]            = $product->get_name();
      $this->fields[ "text" ]             = $product->get_description();
      $this->fields[ "regularprice" ]     = $product->get_regular_price();
      $this->fields[ "saleprice" ]        = $product->get_sale_price();
      $this->fields[ "price" ]            = $product->get_price();
      $this->fields[ "currencysymbol" ]   = get_woocommerce_currency_symbol();
      $this->fields[ "soldindiviually" ]  = $product->get_sold_individually();
      $this->fields[ "datemodified" ]     = $product->get_date_modified();
      $this->fields[ "datecreated" ]      = $product->get_date_created();
      $this->fields[ "status" ]           = $product->get_status();
      $this->fields[ "featured" ]         = $product->get_featured();
      $this->fields[ "sku" ]              = $product->get_sku();
      $this->fields[ "availability" ]     = $product->get_stock_status();

      // logical fields
      if ( $this->fields[ "saleprice" ] != $this->fields[ "price" ] ) {
         $this->fields[ "onsale" ]    = "yes";
      } else {
         $this->fields[ "onsale" ]    = "no";
      }
   }
   private function MapKCMS( $post ) {
      $this->fields[ "metapath" ] = get_post_meta( $post->ID, "kcms_content_folder", true );
      $this->fields[ "metaid" ]   = get_post_meta( $post->ID, "kcms_content_file", true );
   }
   private function ImageURL( $wooimage ) {
      // extract img url from woo <img src="...
      $pos = strpos( $wooimage, 'src=' ) + 5;
      $wooimage = substr( $wooimage, $pos, strlen( $wooimage ) );
      $pos = strpos( $wooimage, '"' );
      $wooimage = substr( $wooimage,0 ,$pos );
      return $wooimage;
   }
   public function ConvertTextToSimpleDescription( $text ) {
      $text = strip_tags( $text );
      $text = str_replace ( "\n", " ", $text );
      $text = str_replace ( "\r", " ", $text );
      $text = str_replace ( "&nbsp;", " ", $text );
      $text = preg_replace( '/[\t|\s{2,}]/', ' ', $text);
      while ( strpos ( $text, "  ") !== false ) {
         $text = str_replace ( "  ", " ", $text );
      }
      return trim( $text );
   }
   public function MapGoogleValues( $value ) {
      switch ( $value ) {
         case "instock"    : $value = "in_stock";     break;
         case "outofstock" : $value = "out_of_stock"; break;
         case "onbackorder": $value = "in_stock";     break;
         default: break;
      }
      return $value;
   }
   private function MapCurrencySymbol( $symbol ) {
      switch ( $symbol ) {
         case "&#36;":                       return "USD"; break;
         case "$":                           return "USD"; break;
         case "&dollar":                     return "USD"; break;
         case "&#162;":                      return "EUR"; break;
         case "&cent;":                      return "EUR"; break;
         case "&#128;":                      return "EUR"; break;
         case "&euro;":                      return "EUR"; break;
         case "&#163;":                      return "GBP"; break;
         case "&pound;":                     return "GBP"; break;
         case "&#165;":                      return "JPY"; break;
         case "&yen;":                       return "JPY"; break;
         case "&#8355;":                     return "XPF"; break;
         case "&#8356;":                     return "TRY"; break;
         case "&#8359;":                     return "PTS"; break;
         case "&#x20B9;":                    return "INR"; break;
         case "&#8361;":                     return "KPW"; break;
         case "&#8372;":                     return "UAH"; break;
         case "&#8367;":                     return "GRD"; break;
         case "&#8366;":                     return "MNT"; break;
         case "&#8370;":                     return "PYG"; break;
         case "&#8369;":                     return "PHP"; break;
         case "&#8371;":                     return "AUD"; break;
         case "&#8373;":                     return "GHS"; break;
         case "&#8365;":                     return "LAK"; break;
         case "&#8362;":                     return "ILS"; break;
         case "&#8363;":                     return "VND"; break;
         case "&#76;&#101;&#107;":           return "ALL"; break;
         case "&#1547;":                     return "AFN"; break;
         case "&#36;":                       return "ARS"; break;
         case "&#402;":                      return "AWG"; break;
         case "&#36;":                       return "AUD"; break;
         case "&#1084;&#1072;&#1085;":       return "AZN"; break;
         case "&#36;":                       return "BSD"; break;
         case "&#36;":                       return "BBD"; break;
         case "&#66;&#114;":                 return "BYN"; break;
         case "&#66;&#90;&#36;":             return "BZD"; break;
         case "&#36;":                       return "BMD"; break;
         case "&#36;&#98;":                  return "BOB"; break;
         case "&#75;&#77;":                  return "BAM"; break;
         case "&#80;":                       return "BWP"; break;
         case "&#1083;&#1074;":              return "BGN"; break;
         case "&#82;&#36;":                  return "BRL"; break;
         case "&#36;":                       return "BND"; break;
         case "&#6107;":                     return "KHR"; break;
         case "&#36;":                       return "CAD"; break;
         case "&#36;":                       return "KYD"; break;
         case "&#36;":                       return "CLP"; break;
         case "&#165;":                      return "CNY"; break;
         case "&#36;":                       return "COP"; break;
         case "&#8353;":                     return "CRC"; break;
         case "&#107;&#110;":                return "HRK"; break;
         case "&#8369;":                     return "CUP"; break;
         case "&#75;&#269;":                 return "CZK"; break;
         case "&#107;&#114;":                return "DKK"; break;
         case "&#82;&#68;&#36;":             return "DOP"; break;
         case "&#36;":                       return "XCD"; break;
         case "&#163;":                      return "EGP"; break;
         case "&#36;":                       return "SVC"; break;
         case "&#8364;":                     return "EUR"; break;
         case "&#163;":                      return "FKP"; break;
         case "&#36;":                       return "FJD"; break;
         case "&#162;":                      return "GHS"; break;
         case "&#163;":                      return "GIP"; break;
         case "&#81;":                       return "GTQ"; break;
         case "&#163;":                      return "GGP"; break;
         case "&#36;":                       return "GYD"; break;
         case "&#76;":                       return "HNL"; break;
         case "&#36;":                       return "HKD"; break;
         case "&#70;&#116;":                 return "HUF"; break;
         case "&#107;&#114;":                return "ISK"; break;
         case "&#8377;":                     return "INR"; break;
         case "&#82;&#112;":                 return "IDR"; break;
         case "&#65020;":                    return "IRR"; break;
         case "&#163;":                      return "IMP"; break;
         case "&#8362;":                     return "ILS"; break;
         case "&#74;&#36;":                  return "JMD"; break;
         case "&#165;":                      return "JPY"; break;
         case "&#163;":                      return "JEP"; break;
         case "&#1083;&#1074;":              return "KZT"; break;
         case "&#8361;":                     return "KPW"; break;
         case "&#8361;":                     return "KRW"; break;
         case "&#1083;&#1074;":              return "KGS"; break;
         case "&#8365;":                     return "LAK"; break;
         case "&#163;":                      return "LBP"; break;
         case "&#36;":                       return "LRD"; break;
         case "&#1076;&#1077;&#1085;":       return "MKD"; break;
         case "&#82;&#77;":                  return "MYR"; break;
         case "&#8360;":                     return "MUR"; break;
         case "&#36;":                       return "MXN"; break;
         case "&#8366;":                     return "MNT"; break;
         case "&#77;&#84;":                  return "MZN"; break;
         case "&#36;":                       return "NAD"; break;
         case "&#8360;":                     return "NPR"; break;
         case "&#402;":                      return "ANG"; break;
         case "&#36;":                       return "NZD"; break;
         case "&#67;&#36;":                  return "NIO"; break;
         case "&#8358;":                     return "NGN"; break;
         case "&#8361;":                     return "KPW"; break;
         case "&#107;&#114;":                return "NOK"; break;
         case "&#65020;":                    return "OMR"; break;
         case "&#8360;":                     return "PKR"; break;
         case "&#66;&#47;&#46;":             return "PAB"; break;
         case "&#71;&#115;":                 return "PYG"; break;
         case "&#83;&#47;&#46;":             return "PEN"; break;
         case "&#8369;":                     return "PHP"; break;
         case "&#122;&#322;":                return "PLN"; break;
         case "&#65020;":                    return "QAR"; break;
         case "&#108;&#101;&#105;":          return "RON"; break;
         case "&#1088;&#1091;&#1073;":       return "RUB"; break;
         case "&#163;":                      return "SHP"; break;
         case "&#65020;":                    return "SAR"; break;
         case "&#1044;&#1080;&#1085;&#46;":  return "RSD"; break;
         case "&#8360;":                     return "SCR"; break;
         case "&#36;":                       return "SGD"; break;
         case "&#36;":                       return "SBD"; break;
         case "&#83;":                       return "SOS"; break;
         case "&#82;":                       return "ZAR"; break;
         case "&#8361;":                     return "KRW"; break;
         case "&#8360;":                     return "LKR"; break;
         case "&#107;&#114;":                return "SEK"; break;
         case "&#67;&#72;&#70;":             return "CHF"; break;
         case "&#36;":                       return "SRD"; break;
         case "&#163;":                      return "SYP"; break;
         case "&#78;&#84;&#36;":             return "TWD"; break;
         case "&#3647;":                     return "THB"; break;
         case "&#84;&#84;&#36;":             return "TTD"; break;
         case "&#;":                         return "TRY"; break;
         case "&#36;":                       return "TVD"; break;
         case "&#8372;":                     return "UAH"; break;
         case "&#163;":                      return "GBP"; break;
         case "&#36;":                       return "USD"; break;
         case "&#36;&#85;":                  return "UYU"; break;
         case "&#1083;&#1074;":              return "UZS"; break;
         case "&#66;&#115;":                 return "VEF"; break;
         case "&#8363;":                     return "VND"; break;
         case "&#65020;":                    return "YER"; break;
         case "&#90;&#36;":                  return "ZWD"; break;
         default:                            return $symbol; break;
      }
   }
} // end class leftsellProduct
?>