<?php
/**
 * Plugin Name:       LeftSell
 * Plugin URI:        https://leftsell.com/
 * Description:       Provides Wordpress options and improves shopping for products and services. 
 * Version:           1.0.0
 * Requires at least: 5.2
 * Requires PHP:      5.4
 * Tested up to:      5.5
 * Stable tag:        5.5
 * Author:            Kundschaft Schweiz
 * Author URI:        https://kundschaft.ch/
 * Text Domain:       leftsell
 * Domain Path:       /languages
 * License:           GPL v2 or later
 * License URI:       https://www.gnu.org/licenses/gpl-2.0.html
 * 
 * LeftSell is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * any later version.
 *  
 * LeftSell is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *  
 * You should have received a copy of the GNU General Public License
 * along with LeftSell. If not, see https://www.gnu.org/licenses/gpl-2.0.html.
**/

define ( "leftsellVERSION",    "1.0.0" );
define ( "leftsellGATE",       "https://api001.leftsell.com/?rest_route=/leftsellgate/v2/gate/" );
define ( "leftsellINCLUDE" ,   plugin_dir_url( __FILE__ ). 'includes/' );

// load requirements ------------------------------------------------
if ( is_admin() ) {
   require_once ( __DIR__ . '/admin/page-tools.php' );
   require_once ( __DIR__ . '/admin/page-com.php' );
}
require_once ( __DIR__ . '/includes/ls_tools.php' );
require_once ( __DIR__ . '/includes/ls_helper.php' );
require_once ( __DIR__ . '/includes/ls_products.php' );
require_once ( __DIR__ . '/includes/ls_messages.php' );

// translations      ------------------------------------------------
function leftsell_load_plugin_textdomain() {
    load_plugin_textdomain( 'leftsell', FALSE, basename( dirname( __FILE__ ) ) . '/languages/' );
}
add_action( 'plugins_loaded', 'leftsell_load_plugin_textdomain' );

// styles and scripts -----------------------------------------------
function leftsell_style_script() {
   wp_enqueue_style ( 'leftsellcss',  plugin_dir_url( __FILE__ ). 'includes/files/leftsell.css', false, leftsellVERSION, 'all');
   wp_enqueue_script( 'leftsellajax', plugin_dir_url( __FILE__ ). 'includes/files/leftsell_ajax.js',  false, leftsellVERSION, 'all');
   wp_enqueue_script( 'leftselljs',   plugin_dir_url( __FILE__ ). 'includes/files/leftsell.js',  false, leftsellVERSION, 'all');
   wp_localize_script('leftsellajax', 'leftsell', array( 'pluginsUrl' => plugin_dir_url( __FILE__ )));
}
add_action( 'admin_enqueue_scripts', 'leftsell_style_script' );

// start REST route -------------------------------------------------
add_action( 'rest_api_init', function () { // required for news / bugreports / featurerequest 
   register_rest_route( 'leftsell/v2', '/crafts', array(
      'methods' => 'GET',
      'callback' => 'leftsellRESTHandler',
      'permission_callback' => function () {
         $objShop = new leftsellShop();
         switch ( $objShop->m_intEnabled ) {
            case "1": $objShop = null; return '__return_true';
            default:  $objShop = null; return '__return_false';
         }
      }
   ) );
} );
add_filter( 'https_local_ssl_verify', '__return_false' );
add_filter( 'backwpup_cacert_bundle', '__return_false' );

// check for message defintions of today
leftSellGetMsgDefinitions();

// menus ------------------------------------------------------------
function leftsell_plugin_create_menu() {
   $imagedata = esc_html( file_get_contents( __DIR__ .  '/includes/images/leftsell-icon.src' ) );
   add_menu_page( 'LeftSell', 'LeftSell', 'manage_options','leftsell','leftsell_page_tools', $imagedata, 56 );
   add_submenu_page(
      'leftsell',                                        // parent slug
      esc_html__( 'LeftSell Options', 'leftsell' ),      // page title
      esc_html__( 'Options', 'leftsell' ),               // menu title
      'manage_options',                                  // capability
      'leftsell',                                        // slug
      'leftsell_page_tools'                              // callback
   ); 
   add_submenu_page(
      'leftsell',                                        // parent slug
      esc_html__( 'Take part of LeftSell', 'leftsell' ), // page title
      esc_html__( 'Communicate', 'leftsell' ),           // menu title
      'manage_options',                                  // capability
      'leftsell-com',                                    // slug
      'leftsell_page_com'                                // callback
   ); 
}
add_action( 'admin_menu', 'leftsell_plugin_create_menu' );

// AJAX -------------------------------------------------------------
function leftsellAJAX_RegisterScripts() {
   wp_register_script( 'leftsellAJAX', true , array( 'jquery' ), leftsellVERSION, true );
   wp_enqueue_script ( 'leftsellAJAX' );
   wp_localize_script( 'leftsellAJAX', 'leftsellAJAX_AJAX', array( 'ajax_url' => admin_url( 'admin-ajax.php' ) , 'security' => wp_create_nonce('leftsellAJAX_callback') ) );
}
add_action( 'admin_enqueue_scripts',       'leftsellAJAX_RegisterScripts' );
add_action( 'wp_ajax_leftsellAJAX_action', 'leftsellAJAX_callback' );
function leftsellAJAX_callback() { 
   if ( wp_verify_nonce( sanitize_text_field( $_POST['nonce'] ), 'leftsellAJAX_callback' ) == false) { 
      esc_html__( "403", "leftsell" );
      wp_die();
   }
   if (!isset($_POST["params"])) { esc_html__( "4032", "leftsell" ); wp_die(); }
   $params = sanitize_text_field( $_POST["params"] );
   $params = str_replace("%20", " ", $params);
   echo leftsellHandleAJAX( $params );
   wp_die();
}
function leftsellHandleAJAX( $param ) { 
   $objJSON = new leftsellJSON();
   $aryParams = $objJSON->FromJSON( $param );
   if ( $aryParams == false ) { return esc_html__( "404", "leftsell" ); }
   if ( !isset( $aryParams["call"]) ) { return esc_html__( "405", "leftsell" ); }
   switch ( $aryParams["call"] ) {
      case "changeoption":
         if ( !isset( $aryParams[ "option" ]) ) { return esc_html__( "406", "leftsell" ); }
         if ( $aryParams[ "option" ] == "" )    { return esc_html__( "407", "leftsell" ); }
         $option = sanitize_text_field( $aryParams[ "option" ] );
         $value = get_option ( $option );
         $value = sanitize_text_field( $value );
         $deprecated = null;
         $autoload = 'no';
         if ( $value === false ) { 
            add_option ( $option, "1", $deprecated, $autoload );
         }
         if ( $value == 1 ) { 
            update_option ( $option, "0", $deprecated, $autoload );
         } else {  
            update_option ( $option, "1", $deprecated, $autoload );
         }
         $objUI = new leftsellUI();
         return $objUI->GetOptionSwitch( $option );
         break;
      case "changetextoption": 
         if ( !isset( $aryParams[ "option" ]) ) { return esc_html__( "506", "leftsell" ); }
         if ( !isset( $aryParams[ "value" ]) )  { return esc_html__( "507", "leftsell" ); }
         if ( $aryParams[ "option" ] == "" )    { return esc_html__( "508", "leftsell" ); }
         $option = sanitize_text_field( $aryParams["option"] );
         $value = html_entity_decode( $aryParams["value"] );
         $value = sanitize_text_field( $value );
         $oldvalue = get_option ( $option );
         $deprecated = null;
         $autoload = 'no';
         if ( $oldvalue === false ) { 
            add_option ( $option, $value, $deprecated, $autoload );
         } else {
            update_option ( $option, $value, $deprecated, $autoload );
         }
         return "OK";
         break;
      case "creategooglesitemap":
         leftsell_CreateGoogleXML();
         return "OK";
         break;
      case "creategoogleproductmap":
         return leftsell_CreateGoogleProductMap();
         break;
      case "sendmessage":
         return leftSellSendMessage( $aryParams );
         break;
      case "reportbug":
         $objBug = new leftsellCom();
         return $objBug->ReportBug( $aryParams );
         break;
      case "requestfeature":
         $objFeature = new leftsellCom();
         return $objFeature->RequestFeature( $aryParams );
         break;
      default: return esc_html__( "999", "leftsell" );
   }
}

// plugin activation ------------------------------------------------
function leftsell_activation() {
   $objMsg = new leftsellMessage( "plugin_activation" );
   $result = $objMsg->SendMessage();
   $objMsg = null;
   if ( intval( $result == 0 ) ) {
      wp_die( $result );
   } else {
      $deprecated = null;
      $autoload = 'no';
      update_option ( "leftsell_shop_id", $result, $deprecated, $autoload );
      update_option ( "leftsell_shop_enabled", 1, $deprecated, $autoload );
   }
}
register_activation_hook( __FILE__, 'leftsell_activation' );

// plugin deactivation ----------------------------------------------
function leftsell_deactivation() {
   $objMsg = new leftsellMessage( "plugin_deactivation" );
   $result = $objMsg->SendMessage();
   $objMsg = null;
   if ( intval( $result != "OK" ) ) {
      wp_die( $result );
   } else {
      $deprecated = null;
      $autoload = 'no';
      update_option ( "leftsell_shop_enabled", 0 , $deprecated, $autoload );
   }
}
register_deactivation_hook( __FILE__, 'leftsell_deactivation' );

// plugin uninstall -------------------------------------------------
function leftsell_uninstall() {
   $objMsg = new leftsellMessage( "plugin_deactivation" );
   $objMsg->SendMessage();
   $objMsg = null;
   // remove all options
   delete_option( "leftsell_additionalheader" );
   delete_option( "leftsell_adminmessages" );
   delete_option( "leftsell_adminthanks" );
   delete_option( "leftsell_bugregports" );
   delete_option( "leftsell_description" );
   delete_option( "leftsell_featurerequests" );
   delete_option( "leftsell_googlebreadcrumbs" );
   delete_option( "leftsell_googleorganisation" );
   delete_option( "leftsell_googleproductxml" );
   delete_option( "leftsell_googlesitemap" );
   delete_option( "leftsell_keywords" );
   delete_option( "leftsell_messagedefintions" );
   delete_option( "leftsell_messageupdate" );
   delete_option( "leftsell_ogimage" );
   delete_option( "leftsell_ogtitle" );
   delete_option( "leftsell_ogtype" );
   delete_option( "leftsell_ogurl" );
   delete_option( "leftsell_removeshortlinks" );
   delete_option( "leftsell_robotstext" );
   delete_option( "leftsell_shop_adult" );
   delete_option( "leftsell_shop_blocked" );
   delete_option( "leftsell_shop_brand" );
   delete_option( "leftsell_shop_enabled" );
   delete_option( "leftsell_shop_gtin" );
   delete_option( "leftsell_shop_id" );
   delete_option( "leftsell_shop_itemcondition" );
   delete_option( "leftsell_shop_mpn" );
   delete_option( "leftsell_shop_sku" );
   delete_option( "leftsell_titletag" );
   delete_option( "leftsell_woo_storealerts" );
   delete_option( "leftsell_woo_themesupport" );
   delete_option( "leftsell_shop_description_tab_heading" );
   delete_option( "leftsell_shop_service" );
   delete_option( "leftsell_footer" );
   delete_option( "leftsell_comments_author" );
   delete_option( "leftsell_comments_email" );
   delete_option( "leftsell_comments_url" );
   delete_option( "leftsell_comments_cookies" );
}
register_uninstall_hook( __FILE__, 'leftsell_uninstall' );
?>